@@ -213,12 +213,16 @@ def server_websuite(user='webuser', python_version='3.4.2', only_pypy=True, pypy
 
     if only_pypy:
         py_pypy(pypy_version)
+
     else:
         py_python(python_version, compatible=compatible, pypy=pypy_version)
 
+
     pip('tornadoez')
     pip('pyjwt')
-    pip('pillow')
+
+    utils_imagelib()
+    pip_c('pillow')
     pip('pymongo')
     pip('redis')
     pip('pymysql')
